pub struct Input {
pub server: Option<FHIRUri>,
pub resource: Vec<FHIRCode>,
}Fields
server: Option<FHIRUri>The canonical URL - use this if the subset is not invoked on an instance (or on the /metadata end-point)
resource: Vec<FHIRCode>A resource that the client would like to include in the return